import { initExpViewer } from "@queenjs-modules/queentree-explorer-viewer";
import { PageListController, UploadController } from "@queenjs/controllers";
import { ModuleRoot } from "queenjs";
import { collocationAction } from "./module/actions/collocation";
import { designAction } from "./module/actions/design";
import { initAction } from "./module/actions/init";
import { helper } from "./module/helper";
import { https } from "./module/http";
import { designStore } from "./module/stores/design";

export class CollocationModule extends ModuleRoot {
  config = this.setConfig({});
  https = this.createHttps([https]);
  store = this.createStore(designStore);
  helper = this.createHelper(helper);
  actions = this.createActions([initAction, collocationAction, designAction]);

  controls = {
    listCtrl: new PageListController(this.config?.httpConfig),
    uploader: new UploadController({
      httpConfig: {
        baseURL: "https://www.infish.cn/tree/v1/assetcenter",
      },
      dir: "queentree",
    }),
  };
  // modules = this.useModules({
  //   expViewer: initExpViewer,
  // });

  onReady() {
    this.controls.listCtrl.setCrudPrefix("/match/style");
  }
}

export const { initCollocation, useCollocation } =
  CollocationModule.hook("Collocation");
