import { useCollocation } from "@/modules/collocation";
import { css } from "@linaria/core";
import { IconAddImg } from "@queenjs/icons";
import { Image } from "@queenjs/ui";
import { Button } from "ant-design-vue";
import { queenApi, useModal } from "queenjs";
import { defineComponent, reactive } from "vue";
import { object } from "vue-types";
import DesignListModel from "./DesignListModel";

export default defineComponent({
  props: {
    value: object().def({}),
  },
  emits: ["update:value"],
  setup(props, { emit }) {
    const collocation = useCollocation();
    const modal = useModal();

    const state = reactive({
      thumbnail: props.value.thumbnail,
    }) as any;

    const selectDesign = async () => {
      collocation.showModal(<DesignListModel />, {
        // title: "选择模型",
        width: "800px",
        onOk: async (v: any) => {
          if (v) {
            const folder = v[0][0];
            const asset = await folder.getAssetDetail(true);
            emit("update:value", asset);

            const DefaultThumbnail = require("@/assets/images/default.png");
            state.thumbnail = folder.state?.thumbnail;
            if (!state.thumbnail.url) {
              state.thumbnail.url = DefaultThumbnail;
            }
          }
        },
        onCancel: () => modal.cancel(),
      });
    };

    const changeThumbnail = async () => {
      const [blob] = await queenApi.selectFile({ accept: "image/*" });
      // console.log("blob: ", blob);

      if (blob) {
        if (!["image/png", "image/jpeg"].includes(blob.type)) {
          queenApi.messageError("上传文件格式不正确，仅支持jpg/png格式");
          return false;
        }
      }
      const res = await collocation.controls.uploader.uploadFile(
        blob,
        "thumbnail"
      );
      if (res) {
        const { value } = props;
        value.thumbnail = res;
        state.thumbnail = res;
        emit("update:value", value);
      }
    };

    return () => {
      const { thumbnail } = state;
      return (
        <div>
          {thumbnail && thumbnail.url ? (
            <div class={DesignSelect}>
              <Image src={thumbnail.url} size={98} />
              <div class="thumbnail_cover">
                <Button type="text" onClick={selectDesign}>
                  更换款式
                </Button>
                <Button type="text" onClick={changeThumbnail}>
                  更换封面
                </Button>
              </div>
            </div>
          ) : (
            <div class={DesignSelect} onClick={selectDesign}>
              <IconAddImg class="text-30px mb-10px" />
              <span class="text-12px">点击选择</span>
            </div>
          )}
        </div>
      );
    };
  },
});

const DesignSelect = css`
  position: relative;
  width: 98px;
  height: 98px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  padding: 10px;
  border-radius: 4px;
  color: @inf-primary-color;
  background: #eef1fe;
  cursor: pointer;
  img {
    width: 100%;
    height: 100%;
    object-fit: contain;
  }

  &:hover {
    .thumbnail_cover {
      display: flex;
      flex-flow: column;
      justify-content: center;
    }
  }
  .thumbnail_cover {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    padding: 10px;
    display: none;
    background-color: rgba(0, 0, 0, 0.2);
    button.ant-btn {
      padding: 0;
      color: @inf-primary-color;
      &:hover {
        background: #f5f6f7;
        border-color: #f5f6f7;
      }
      &:last-child {
        margin-top: 10px;
      }
    }
  }
`;
