import { useCollocation } from "@/modules/collocation";
import { css } from "@linaria/core";
import { IconClose } from "@queenjs/icons";
import { Radio, RadioChangeEvent, Space } from "ant-design-vue";
import { queenApi } from "queenjs";
import { defineComponent } from "vue";
import { useRouter } from "vue-router";

export default defineComponent({
  setup() {
    const router = useRouter();
    const collocation = useCollocation();

    async function close() {
      if (history.state.canSave) {
        const ok = await queenApi.showConfirm({
          title: "提示",
          content: "退出款式设计，当前数据将丢失，是否继续退出。",
          okText: "确定",
        });
        if (!ok) return;
        router.go(-1);
      } else {
        router.go(-1);
      }
    }

    const changeGroup = (e: RadioChangeEvent) => {
      switch (e.target.value) {
        case "add":
          collocation.actions.addMatchCategory();
          break;
        default:
          collocation.store.setEditType(e.target.value);
          break;
      }
    };

    return () => {
      return (
        <div class={headerStyles}>
          <span class="title">搭配定制中心</span>
          <div class="flex-1 text-center">
            <Radio.Group
              buttonStyle="solid"
              optionType="button"
              value={collocation.store.editType}
              options={collocation.store.menuOptions.options}
              onChange={(e) => changeGroup(e)}
            />
          </div>
          <Space>
            <IconClose class="icon_close" type="close" onClick={close} />
          </Space>
        </div>
      );
    };
  },
});

const headerStyles = css`
  grid-area: header;
  height: 64px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  border-bottom: 1px solid #eaeaea;
  padding: 0 20px;
  background-color: #fff;
  .title {
    font-size: 16px;
    font-weight: bold;
    color: #111111;
  }

  .icon_close {
    padding: 10px;
    font-size: 22px;
    font-weight: bold;
    cursor: pointer;
    &:hover {
      opacity: 0.8;
    }
    &:active {
      opacity: 0.6;
    }
  }
`;
