import { css } from "@linaria/core";
import { useQueditor } from "@queenjs-modules/queditor";
import { IconClear, IconEdit, IconUnlock } from "@queenjs/icons";
import { List } from "@queenjs/ui";
import { defineComponent } from "vue";
import { any } from "vue-types";
import MatItem from "./MatItem";

export default defineComponent({
  props: {
    record: any(),
  },
  setup(props) {
    const { controls, components, actions } = useQueditor();
    const { DropView } = components;

    controls.drager.on(
      "drop:selfDrop",
      async (event: DragEvent, { type, data }: any) => {
        console.log(event, type, await data());
      }
    );

    return () => {
      const { record } = props;
      return (
        <DropView name="selfDrop" type={["asset3d.*"]} class="my-10px">
          <div class={groupStyles}>
            <div class="flex items-center justify-between">
              <span>{record.name}</span>
              <div class="icons">
                <IconEdit title="重命名" />
                {/* <IconUngroup  title="修改分组" /> */}
                {/* <IconGroup title="解除分组" /> */}
                {/* <IconLock title="解锁部件" /> */}
                <IconUnlock title="锁定部件" />
                <IconClear title="清空面料" />
              </div>
            </div>
            <div>
              <List data={[]} columns={5} gap="5px">
                {{
                  item: () => <MatItem />,
                  empty: () => (
                    <div class="py-20px text-gray-500 text-center text-12px">
                      暂无数据
                    </div>
                  ),
                }}
              </List>
            </div>
          </div>
        </DropView>
      );
    };
  },
});

const groupStyles = css`
  border: 1px solid transparent;
  border-radius: 4px;
  padding: 10px;
  cursor: pointer;
  transition: all 0.1s ease-in-out;
  &.active,
  &:hover {
    /* background-color: @inf-primary-fade-color; */
    background-color: #eef1fe;
  }
  &.active {
    border: 1px solid @inf-border-color;
  }

  &:hover {
    .icons {
      opacity: 1;
    }
  }
  .icons {
    color: @inf-text-less-color;
    font-size: 18px;
    opacity: 0;
    transition: all 0.1s ease-in-out;
    .inficon {
      margin-left: 5px;
      padding: 2px 3px;
      &:hover {
        background-color: #e1e1e1;
        transition: all 0.1s ease-in-out;
      }
    }
  }
`;
