import { css, cx } from "@linaria/core";
import { IconMore } from "@queenjs/icons";
import { Image } from "@queenjs/ui";
import { Dropdown, Menu } from "ant-design-vue";
import { defineComponent } from "vue";
import { bool, object } from "vue-types";

export default defineComponent({
  props: {
    active: bool().def(true),
    mat: object<PackageMaterial>(),
  },
  emits: ["click", "action"],
  setup(props, { emit }) {
    return () => {
      const { active, mat } = props;
      return (
        <div
          title={mat?.name || "未命名面料"}
          class={cx(MatCardStyle, active && "active")}
          onClick={(e) => {
            e.stopPropagation();
            emit("click");
          }}
        >
          <Image class="mat_card" src={mat?.thumbnail?.url} size={100} />
          {/* {slots.default && slots.default()} */}
          <Dropdown
            overlay={
              <Menu>
                <Menu.Item
                  key="rename"
                  onClick={(e) => {
                    e.stopPropagation();
                    emit("action", "rename");
                  }}
                >
                  重命名
                </Menu.Item>
                <Menu.Item
                  key="delete"
                  onClick={(e) => {
                    e.stopPropagation();
                    emit("action", "delete");
                  }}
                >
                  删除
                </Menu.Item>
              </Menu>
            }
          >
            <IconMore class="btn_action" />
          </Dropdown>
        </div>
      );
    };
  },
});

const MatCardStyle = css`
  position: relative;
  display: inline-block;
  border: 1px solid transparent;
  border-radius: 2px;
  line-height: 1;
  cursor: pointer;
  overflow: hidden;
  user-select: none;

  .mat_card {
    width: 100%;
    border-radius: 2px;
  }

  .inf-image {
    height: 100%;
    object-fit: cover;
  }

  &.active {
    border: 1px solid #5a7bef;
    padding: 1px;
  }
  &:hover {
    .btn_action {
      opacity: 1;
    }
  }
  .btn_action {
    position: absolute;
    right: 3px;
    top: 2px;
    border-radius: 2px;
    padding: 2px;
    color: #fff;
    opacity: 0;
    background-color: rgba(0, 0, 0, 0.3);
    transition: all 0.2s ease;
    &:hover {
      background: rgba(0, 0, 0, 0.4);
    }
    &:active {
      background: rgba(0, 0, 0, 0.5);
    }
  }
`;
