import { css, cx } from "@linaria/core";
import { IconDelete } from "@queenjs/icons";
import { Image, View } from "@queenjs/ui";
import { defineComponent } from "vue";
import { bool, number, object } from "vue-types";

export default defineComponent({
  props: {
    active: bool().def(false),
    ratio: number().def(1),
    data: object().isRequired,
  },
  emits: ["click", "delete"],
  setup(props, { emit, slots }) {
    return () => {
      return (
        <div
          class={cx(itemHoverStyle, props.active && "active")}
          onClick={() => emit("click", props.data)}
        >
          <View ratio={props.ratio}>
            <Image
              class="item_thumbnail"
              src={props.data?.thumbnail?.url}
              size={120}
            />
          </View>
          <IconDelete
            class="btn_action"
            onClick={(e: any) => {
              e.stopPropagation();
              emit("delete", props.data);
            }}
          />
          {props.data.name && (
            <div class="pickerItem_title" title={props.data.name}>
              {props.data.name}
            </div>
          )}
        </div>
      );
    };
  },
});

const itemHoverStyle = css`
  position: relative;
  border: 1px solid transparent;
  border-radius: 0.04rem;
  padding: 1px;
  cursor: pointer;
  overflow: hidden;
  &.active {
    border: 1px solid #5a7bef;
  }
  &:hover {
    .btn_action,
    .pickerItem_title {
      transform: translateY(0);
    }
  }

  .item_thumbnail {
    width: 100%;
    height: 100%;
    border-radius: 0.04rem;
    pointer-events: none;
  }

  .btn_action {
    position: absolute;
    right: 5px;
    top: 5px;
    border-radius: 2px;
    padding: 0.03rem;
    color: #fff;
    font-size: 0.12rem;
    background-color: rgba(0, 0, 0, 0.3);
    transform: translateY(-150%);
    transition: transform 0.3s ease-in-out;
    &:hover {
      background: rgba(0, 0, 0, 0.4);
    }
    &:active {
      background: rgba(0, 0, 0, 0.5);
    }
  }

  .pickerItem_title {
    position: absolute;
    left: 0;
    bottom: 0;
    width: 100%;
    padding: 0.04rem 0.16rem;
    color: #fff;
    font-size: 0.12rem;
    background-color: rgba(0, 0, 0, 0.3);
    transform: translateY(100%);
    transition: transform ease-in-out 0.3s;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden;
  }
`;
