import { useCollocation } from "@/modules/collocation";
import { List } from "@queenjs/ui";
import { Button } from "ant-design-vue";
import { defineComponent } from "vue";
import PanelCard from "../components/PanelCard";
import PanelGroup from "../components/PanelGroup";
import Tools from "../components/Tools";
import ProductItem from "./ProductItem";

export default defineComponent({
  setup() {
    const collocation = useCollocation();

    const handleChange = (key: string, prodGroup: ProductMatching) => {
      switch (key) {
        case "rename":
          collocation.actions.renameProductGroup(prodGroup);
          break;
        case "delete":
          collocation.actions.deleteProductGroup(prodGroup);
          break;
        case "clear":
          collocation.actions.clearProductGroup();
          break;
      }
    };

    function switchProductGroupIndex(
      prodGroup: ProductMatching,
      index: number
    ) {
      console.log("prodGroup: ", prodGroup, index);
    }

    function deletetGroupProduct(prodGroup: ProductMatching, index: number) {
      console.log("prodGroup: ", prodGroup, index);
    }

    function editCategory(key: string) {
      switch (key) {
        case "rename":
          collocation.actions.renameMatchCategory();
          break;
        case "delete":
          collocation.actions.deleteMatchCategory();
          break;
      }
    }

    return () => {
      const { menuOptions, editType } = collocation.store;
      const currentType = menuOptions.options.find((o) => o.value == editType);

      return (
        <PanelCard
          title={currentType?.label}
          onSave={collocation.actions.saveDesign}
          suffix={
            <Tools tools={["rename", "delete"]} onChange={editCategory} />
          }
        >
          <div class="mb-10px">
            <a class="text-14px" onClick={collocation.actions.addCategoryGroup}>
              添加分组
            </a>
          </div>
          {collocation.store.currentGroupList?.length == 0 && (
            <div class="my-30px text-gray-500 text-center text-12px">
              暂无分组
            </div>
          )}
          {collocation.store.currentGroupList?.map(
            (prodGroup: ProductMatching, index: number) => {
              return (
                <PanelGroup
                  key={index}
                  type="asset3d.mesh"
                  title={prodGroup.group}
                  tools={["rename", "clear", "delete"]}
                  target={prodGroup}
                  onChange={(key) => handleChange(key, prodGroup)}
                >
                  <List
                    gap="10px"
                    columns={2}
                    data={prodGroup.productIds || []}
                  >
                    {{
                      item: (productId: string, index: number) => {
                        return (
                          <ProductItem
                            key={productId}
                            ratio={14 / 9}
                            active={prodGroup.index == index}
                            data={collocation.helper.findProductById(productId)}
                            onClick={() =>
                              switchProductGroupIndex(prodGroup, index)
                            }
                            onDelete={() =>
                              deletetGroupProduct(prodGroup, index)
                            }
                          />
                        );
                      },
                      empty: () => (
                        <div class="my-30px text-12px text-center text-gray-500">
                          暂无数据
                        </div>
                      ),
                    }}
                  </List>
                </PanelGroup>
              );
            }
          )}
        </PanelCard>
      );
    };
  },
});
