import { css, cx } from "@linaria/core";
import { useQueditor } from "@queenjs-modules/queditor";
import { defineComponent } from "vue";
import { any, array, bool, string } from "vue-types";
import Tools, { ToolKeys } from "./Tools";

export default defineComponent({
  props: {
    active: bool().def(false),
    title: string(),
    tools: array<ToolKeys>().def(["clear"]),
    target: any(),
    type: string().def("asset3d.*"),
  },
  emits: ["change", "select"],
  setup(props, { emit, slots }) {
    const { components } = useQueditor();
    const { DropView } = components;

    return () => {
      const { active, title, target } = props;
      return (
        <DropView
          name="selfDrop"
          type={[props.type]}
          target={target}
          class="my-10px"
        >
          <div
            class={cx(styles, active && "active")}
            onClick={() => emit("select")}
          >
            <div class="flex items-center justify-between">
              <span>{title || "默认分组"}</span>
              <Tools
                class="tools"
                tools={props.tools}
                onChange={(...args) => emit("change", ...args)}
              />
            </div>
            {slots.default?.()}
          </div>
        </DropView>
      );
    };
  },
});

const styles = css`
  border: 1px solid transparent;
  border-radius: 4px;
  padding: 10px;
  transition: all 0.1s ease-in-out;
  &.active,
  &:hover {
    background-color: #eef1fe;
  }
  &.active {
    border: 1px solid @inf-border-color;
  }
  &:hover {
    .tools {
      opacity: 1;
    }
  }

  .tools {
    opacity: 0;
  }
`;
