import { css } from "@linaria/core";
import { IconClear, IconDelete, IconEdit, IconLock } from "@queenjs/icons";
import { defineComponent } from "vue";
import { array } from "vue-types";

export type ToolKeys = keyof typeof tools;

const tools = {
  rename: (emit: any) => (
    <IconEdit title="重命名" onClick={() => emit("change", "rename")} />
  ),
  clear: (emit: any) => (
    <IconClear title="清空列表" onClick={() => emit("change", "clear")} />
  ),
  delete: (emit: any) => (
    <IconDelete title="删除" onClick={() => emit("change", "delete")} />
  ),
  lock: (emit: any) => (
    <IconLock title="锁定" onClick={() => emit("change", "lock")} />
  ),
};

export default defineComponent({
  props: {
    tools: array<ToolKeys>().def(["clear"]),
  },
  emits: ["change"],
  setup(props, { emit }) {
    return () => (
      <div class={toolStyles} onClick={(e) => e.stopPropagation()}>
        {props.tools?.map((key) => {
          return tools[key](emit);
        })}
      </div>
    );
  },
});

const toolStyles = css`
  color: @inf-text-less-color;
  font-size: 18px;
  transition: all 0.1s ease-in-out;
  .inficon {
    margin-left: 5px;
    padding: 2px 3px;
    cursor: pointer;
    &:hover {
      background-color: #e1e1e1;
      transition: all 0.1s ease-in-out;
    }
  }
`;
