import { useCollocation } from "@/modules/collocation";
import { css } from "@linaria/core";
import { IconDelete } from "@queenjs/icons";
import { Button, Switch } from "ant-design-vue";
import { queenApi } from "queenjs";
import { defineComponent } from "vue";
import { any } from "vue-types";

export default defineComponent({
  props: {
    value: any(),
  },
  emits: ["change"],
  setup(props, { emit }) {
    const collocation = useCollocation();

    const addCate = async () => {
      if (props.value && props.value.length >= 5) {
        queenApi.messageInfo("暂时不支持添加更多的分类");
        return false;
      }

      const res = await queenApi.showInput({
        title: "分类名称",
        placeholder: "请输入分类名称",
        maxLength: 4,
      });
      if (!res) return;

      const newCate = { name: res, use: true };
      const value = props.value ? [...props.value] : [];
      value.push(newCate);
      emit("change", value);
    };

    const switchChange = (checked: boolean, i: number) => {
      const value = [...props.value];
      value[i].use = checked;
      emit("change", value);
    };

    const delCate = (i: number) => {
      const value = [...props.value];
      value.splice(i, 1);
      emit("change", value);
    };

    return () => {
      return (
        <div class={CategoryView}>
          <div class={"top"}>
            <div>款式分类</div>
            <Button
              ghost
              shape="round"
              size="small"
              type="primary"
              onClick={addCate}
            >
              添加+
            </Button>
          </div>
          {props.value && props.value.length > 0 && (
            <div class={"cate_list"}>
              <div class={"list_top"}>
                <div>分类名称</div>
                <div>是否展示在首页</div>
                <div>操作</div>
              </div>
              {props.value.map((e: any, i: number) => {
                return (
                  <div key={i} class={"list_item"}>
                    <div>{e.name}</div>
                    <div>
                      <Switch
                        size="small"
                        checked={e.use}
                        // onChange={(checked) => switchChange(checked, i)}
                      />
                    </div>
                    <div>
                      <Button
                        type="text"
                        icon={<IconDelete type="delete" />}
                        onClick={() => {
                          delCate(i);
                        }}
                      ></Button>
                    </div>
                  </div>
                );
              })}
            </div>
          )}
        </div>
      );
    };
  },
});

const CategoryView = css`
  .top {
    margin-bottom: 12px;
    display: flex;
    justify-content: space-between;
    align-items: center;
  }
  .cate_list {
    border: 1px solid #ccc;
    border-radius: 2px;
    .list_top,
    .list_item {
      display: flex;
      align-items: center;
      border-bottom: 1px solid #ccc;
      & > div {
        flex: 1;
        text-align: center;
        padding: 5px 10px;
      }
      &:last-child {
        border-bottom: none;
      }
    }
  }
`;
