import { css } from "@linaria/core";
import { Layout, Menu } from "ant-design-vue";
import { defineComponent, onMounted, reactive } from "vue";
import { useRoute } from "vue-router";
import { menuData } from "../router";
import AvatarDropDown from "./AvatarDropDown";

const { Header, Sider, Content } = Layout;

export default defineComponent({
  setup() {
    const state = reactive({
      menuKey: ["design"],
    });

    const menuChange = (keyPath: string[]) => {
      state.menuKey = keyPath;
    };

    onMounted(() => {
      const data: any = useRoute();
      state.menuKey = [data.path];
    });

    return () => {
      return (
        <Layout class={HomeStyle}>
          <Sider
            class="overflow-hidden"
            width="250px"
            trigger={null}
            collapsible
          >
            <h3 class="text-light-200 text-center py-20px">搭配定制</h3>
            <Menu
              theme="dark"
              selectedKeys={state.menuKey}
              mode="inline"
              onSelect={(item: any) => {
                menuChange(item.keyPath);
              }}
            >
              {menuData.children.map((menu: any) => {
                if (menu.children?.length) {
                  return (
                    <Menu.SubMenu title={menu.name}>
                      {menu.children.map((submenu: any) => {
                        if (submenu.hideInMenu) return null;
                        return (
                          <Menu.Item key={submenu.path}>
                            <router-link to={submenu.path}>
                              {submenu.name}
                            </router-link>
                          </Menu.Item>
                        );
                      })}
                    </Menu.SubMenu>
                  );
                }
                return (
                  <Menu.Item key={menu.path}>
                    <router-link to={menu.path}>{menu.name}</router-link>
                  </Menu.Item>
                );
              })}
            </Menu>
          </Sider>
          <Layout>
            <Header class="layout_background text-right">
              <AvatarDropDown />
            </Header>
            <Content
              class="layout_background"
              style={{
                margin: "24px 16px",
                minHeight: 280,
              }}
            >
              <router-view />
            </Content>
          </Layout>
        </Layout>
      );
    };
  },
});

const HomeStyle = css`
  width: 100%;
  height: 100vh;
  .ant-layout-content {
    flex: 1;
    overflow: auto;
  }
  .layout_background {
    background-color: #fff;
  }
`;
